@@ -3,10 +3,12 @@
 cmd_pkg_map=(
     "fence_apc:fence-agents-apc"
     "fence_apc_snmp:fence-agents-apc-snmp"
+    "fence_amt:None"
     "fence_bladecenter:fence-agents-bladecenter"
     "fence_brocade:fence-agents-brocade"
     "fence_cisco_mds:fence-agents-cisco-mds"
     "fence_cisco_ucs:fence-agents-cisco-ucs"
+    "fence_compute:fence-agents-compute"
     "fence_drac5:fence-agents-drac5"
     "fence_eaton_snmp:fence-agents-eaton-snmp"
     "fence_eps:fence-agents-eps"
@@ -23,7 +25,7 @@ cmd_pkg_map=(
     "fence_intelmodular:fence-agents-intelmodular"
     "fence_ipdu:fence-agents-ipdu"
     "fence_ipmilan:fence-agents-ipmilan"
-    "fence_ironic:fence-agents-ironic"
+    "fence_ironic:None"
     "fence_kdump:fence-agents-kdump"
     "fence_rhevm:fence-agents-rhevm"
     "fence_rsb:fence-agents-rsb"
